[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PATCH] xen/balloon: rename alloc/free_xenballooned_pages



alloc_xenballooned_pages() and free_xenballooned_pages() are used as
direct replacements of xen_alloc_unpopulated_pages() and
xen_free_unpopulated_pages() in case CONFIG_XEN_UNPOPULATED_ALLOC isn't
defined.

Guard both functions with !CONFIG_XEN_UNPOPULATED_ALLOC and rename them
to the xen_*() variants they are replacing. This allows to remove some
ifdeffery from the xen.h header file.

Signed-off-by: Juergen Gross <jgross@xxxxxxxx>
---
 drivers/xen/balloon.c | 18 ++++++++++--------
 include/xen/balloon.h |  3 ---
 include/xen/xen.h     |  6 ------
 3 files changed, 10 insertions(+), 17 deletions(-)

diff --git a/include/xen/balloon.h b/include/xen/balloon.h
index 95a4187f263b..d6ee920fafa4 100644
--- a/include/xen/balloon.h
+++ b/include/xen/balloon.h
@@ -27,9 +27,6 @@ extern struct balloon_stats balloon_stats;
 
 void balloon_set_new_target(unsigned long target);
 
-int alloc_xenballooned_pages(int nr_pages, struct page **pages);
-void free_xenballooned_pages(int nr_pages, struct page **pages);
-
 #ifdef CONFIG_XEN_BALLOON
 void xen_balloon_init(void);
 #else
diff --git a/include/xen/xen.h b/include/xen/xen.h
index 43efba045acc..9f031b5faa54 100644
--- a/include/xen/xen.h
+++ b/include/xen/xen.h
@@ -52,13 +52,7 @@ bool xen_biovec_phys_mergeable(const struct bio_vec *vec1,
 extern u64 xen_saved_max_mem_size;
 #endif
 
-#ifdef CONFIG_XEN_UNPOPULATED_ALLOC
 int xen_alloc_unpopulated_pages(unsigned int nr_pages, struct page **pages);
 void xen_free_unpopulated_pages(unsigned int nr_pages, struct page **pages);
-#else
-#define xen_alloc_unpopulated_pages alloc_xenballooned_pages
-#define xen_free_unpopulated_pages free_xenballooned_pages
-#include <xen/balloon.h>
-#endif
 
 #endif /* _XEN_XEN_H */
diff --git a/drivers/xen/balloon.c b/drivers/xen/balloon.c
index 98fae43d4cec..35fac7fb513a 100644
--- a/drivers/xen/balloon.c
+++ b/drivers/xen/balloon.c
@@ -575,6 +575,7 @@ void balloon_set_new_target(unsigned long target)
 }
 EXPORT_SYMBOL_GPL(balloon_set_new_target);
 
+#ifndef CONFIG_XEN_UNPOPULATED_ALLOC
 static int add_ballooned_pages(int nr_pages)
 {
        enum bp_state st;
@@ -603,12 +604,12 @@ static int add_ballooned_pages(int nr_pages)
 }
 
 /**
  * alloc_xenballooned_pages - get pages that have been ballooned out
  * @nr_pages: Number of pages to get
  * @pages: pages returned
  * @return 0 on success, error otherwise
  */
-int alloc_xenballooned_pages(int nr_pages, struct page **pages)
+int xen_alloc_unpopulated_pages(int nr_pages, struct page **pages)
 {
        int pgno = 0;
        struct page *page;
@@ -645,7 +646,7 @@ int alloc_xenballooned_pages(int nr_pages, struct page 
**pages)
        return 0;
  out_undo:
        mutex_unlock(&balloon_mutex);
-       free_xenballooned_pages(pgno, pages);
+       xen_free_unpopulated_pages(pgno, pages);
        /*
         * NB: free_xenballooned_pages will only subtract pgno pages, but since
         * target_unpopulated is incremented with nr_pages at the start we need
@@ -654,14 +655,14 @@ int alloc_xenballooned_pages(int nr_pages, struct page 
**pages)
        balloon_stats.target_unpopulated -= nr_pages - pgno;
        return ret;
 }
-EXPORT_SYMBOL(alloc_xenballooned_pages);
+EXPORT_SYMBOL(xen_alloc_unpopulated_pages);
 
 /**
  * free_xenballooned_pages - return pages retrieved with get_ballooned_pages
  * @nr_pages: Number of pages
  * @pages: pages to return
  */
-void free_xenballooned_pages(int nr_pages, struct page **pages)
+void xen_free_unpopulated_pages(int nr_pages, struct page **pages)
 {
        int i;
 
@@ -680,9 +681,9 @@ void free_xenballooned_pages(int nr_pages, struct page 
**pages)
 
        mutex_unlock(&balloon_mutex);
 }
-EXPORT_SYMBOL(free_xenballooned_pages);
+EXPORT_SYMBOL(xen_free_unpopulated_pages);
 
-#if defined(CONFIG_XEN_PV) && !defined(CONFIG_XEN_UNPOPULATED_ALLOC)
+#if defined(CONFIG_XEN_PV)
 static void __init balloon_add_region(unsigned long start_pfn,
                                      unsigned long pages)
 {
@@ -705,6 +706,7 @@ static void __init balloon_add_region(unsigned long 
start_pfn,
        balloon_stats.total_pages += extra_pfn_end - start_pfn;
 }
 #endif
+#endif
 
 static int __init balloon_init(void)
 {
@@ -603,12 +604,12 @@ static int add_ballooned_pages(int nr_pages)
 
 /**
- * alloc_xenballooned_pages - get pages that have been ballooned out
+ * xen_alloc_unpopulated_pages - get pages that have been ballooned out
  * @nr_pages: Number of pages to get
  * @pages: pages returned
@@ -654,14 +655,14 @@ int alloc_xenballooned_pages(int nr_pages, struct page 
 
 /**
- * free_xenballooned_pages - return pages retrieved with get_ballooned_pages
+ * xen_free_unpopulated_pages - return pages retrieved with get_ballooned_pages
  * @nr_pages: Number of pages
  * @pages: pages to return
-- 
2.26.2




 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.